3 ms·
A big part of it is because they're repeatedly walking the same path while reading and writing it. I got a 20% performance improvement on FreeBSD+ZFS with this
by ori_b 9y ago
A big part of it is because they're repeatedly walking the same path while reading and writing it. I got a 20% performance improvement on FreeBSD+ZFS with this change, which merely opens an fd, and uses that to stat and write, cutting the number of path traversals in half:
https://eigenstate.org/paste/d41e3b69d258e3b52f7cee7a9921f027 https://eigenstate.org/paste/d41e3b69d258e3b52f7cee7a9921f02...
- justinclift 9y agoCool, have you pointed them at it? :)